import { createContext, useContext, useReducer, ReactNode } from "react";
import { Product } from "@shared/schema";

interface CartItem {
  product: Product;
  quantity: number;
}

interface CartState {
  items: CartItem[];
  total: number;
}

type CartAction =
  | { type: "ADD_ITEM"; payload: { product: Product; quantity: number } }
  | { type: "REMOVE_ITEM"; payload: { productId: number } }
  | { type: "UPDATE_QUANTITY"; payload: { productId: number; quantity: number } }
  | { type: "CLEAR_CART" };

const CartContext = createContext<{
  state: CartState;
  dispatch: React.Dispatch<CartAction>;
} | null>(null);

function cartReducer(state: CartState, action: CartAction): CartState {
  switch (action.type) {
    case "ADD_ITEM": {
      const existingItem = state.items.find(
        item => item.product.id === action.payload.product.id
      );

      if (existingItem) {
        return {
          ...state,
          items: state.items.map(item =>
            item.product.id === action.payload.product.id
              ? { ...item, quantity: item.quantity + action.payload.quantity }
              : item
          ),
          total: state.total + parseFloat(action.payload.product.price) * action.payload.quantity
        };
      }

      return {
        ...state,
        items: [...state.items, action.payload],
        total: state.total + parseFloat(action.payload.product.price) * action.payload.quantity
      };
    }
    case "REMOVE_ITEM": {
      const item = state.items.find(item => item.product.id === action.payload.productId);
      if (!item) return state;

      return {
        ...state,
        items: state.items.filter(item => item.product.id !== action.payload.productId),
        total: state.total - parseFloat(item.product.price) * item.quantity
      };
    }
    case "UPDATE_QUANTITY": {
      const item = state.items.find(item => item.product.id === action.payload.productId);
      if (!item) return state;

      return {
        ...state,
        items: state.items.map(item =>
          item.product.id === action.payload.productId
            ? { ...item, quantity: action.payload.quantity }
            : item
        ),
        total:
          state.total -
          parseFloat(item.product.price) * item.quantity +
          parseFloat(item.product.price) * action.payload.quantity
      };
    }
    case "CLEAR_CART":
      return { items: [], total: 0 };
    default:
      return state;
  }
}

export function CartProvider({ children }: { children: ReactNode }) {
  const [state, dispatch] = useReducer(cartReducer, { items: [], total: 0 });

  return (
    <CartContext.Provider value={{ state, dispatch }}>
      {children}
    </CartContext.Provider>
  );
}

export function useCart() {
  const context = useContext(CartContext);
  if (!context) {
    throw new Error("useCart must be used within a CartProvider");
  }
  return context;
}
