import { useQuery } from "@tanstack/react-query";
import { useParams } from "wouter";
import { Product } from "@shared/schema";
import { ImageGallery } from "@/components/ui/image-gallery";
import { Button } from "@/components/ui/button";
import { useCart } from "@/components/cart/cart-context";
import { useToast } from "@/hooks/use-toast";
import { Minus, Plus } from "lucide-react";
import { useState } from "react";

export default function ProductPage() {
  const { id } = useParams<{ id: string }>();
  const { dispatch } = useCart();
  const { toast } = useToast();
  const [quantity, setQuantity] = useState(1);

  const { data: product, isLoading } = useQuery<Product>({
    queryKey: [`/api/products/${id}`],
  });

  const handleAddToCart = () => {
    if (!product) return;

    dispatch({
      type: "ADD_ITEM",
      payload: { product, quantity }
    });

    toast({
      title: "Added to cart",
      description: `${quantity} x ${product.name} added to your cart.`
    });
  };

  if (isLoading) {
    return (
      <div className="container mx-auto px-4 py-12">
        <div className="grid md:grid-cols-2 gap-12">
          <div className="animate-pulse bg-muted aspect-square rounded-lg" />
          <div className="space-y-4">
            <div className="h-8 bg-muted rounded w-3/4" />
            <div className="h-6 bg-muted rounded w-1/4" />
            <div className="space-y-2">
              <div className="h-4 bg-muted rounded" />
              <div className="h-4 bg-muted rounded" />
              <div className="h-4 bg-muted rounded w-2/3" />
            </div>
          </div>
        </div>
      </div>
    );
  }

  if (!product) {
    return (
      <div className="container mx-auto px-4 py-12 text-center">
        <p className="text-muted-foreground">Product not found.</p>
      </div>
    );
  }

  return (
    <div className="container mx-auto px-4 py-12">
      <div className="grid md:grid-cols-2 gap-12">
        <ImageGallery images={product.images} alt={product.name} />
        
        <div className="space-y-6">
          <h1 className="text-3xl font-bold">{product.name}</h1>
          <p className="text-2xl">${parseFloat(product.price).toFixed(2)}</p>
          
          <div>
            <h3 className="font-medium mb-2">Description</h3>
            <p className="text-muted-foreground">{product.description}</p>
          </div>

          <div>
            <h3 className="font-medium mb-2">Quantity</h3>
            <div className="flex items-center space-x-4">
              <Button
                variant="outline"
                size="icon"
                onClick={() => setQuantity(Math.max(1, quantity - 1))}
                disabled={quantity <= 1}
              >
                <Minus className="h-4 w-4" />
              </Button>
              <span className="w-8 text-center">{quantity}</span>
              <Button
                variant="outline"
                size="icon"
                onClick={() => setQuantity(Math.min(product.inStock, quantity + 1))}
                disabled={quantity >= product.inStock}
              >
                <Plus className="h-4 w-4" />
              </Button>
            </div>
          </div>

          <Button
            className="w-full"
            size="lg"
            onClick={handleAddToCart}
            disabled={product.inStock === 0}
          >
            {product.inStock > 0 ? "Add to Cart" : "Out of Stock"}
          </Button>

          {product.inStock <= 5 && product.inStock > 0 && (
            <p className="text-sm text-muted-foreground">
              Only {product.inStock} left in stock
            </p>
          )}
        </div>
      </div>
    </div>
  );
}
